%define ALD_Ver		1.2.4

Name:         yasm

License:      BSD
Summary:      The Yasm Modular Assembler
Group:        Development/Tools
Version:      1.2.0
Release:      1

Source: %{name}-%{version}.tar.xz
Source1: CROSS.sh

%define DestDir		/Compiler
# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
%define target %{_arch}-%{_vendor}-%{_os}%{__isa_bits}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif
%define target_  %{target}-

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin

%define __os_install_post %{nil}

%define CrossDestDir	/Cross

%define _srcrpmdir %{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysdir		%{nil}
%define csysbindir	/usr/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir %{_topdir}/SRPMS/%{ALD_Ver}

%define target %{_arch}-%{_os}%{_gnu}
%define target_  %{nil}

%endif # !_CROSS || !TARGETBUILD_CROSS

%define docdir %{_defaultdocdir}/%{name}

# ------------------- description ------------------------------------
%description
The Yasm Modular Assembler is a portable, retargetable assembler written under 
the new (2 or 3 clause) BSD license. 
Yasm currently supports the x86 and AMD64 instruction sets, 
accepts NASM and GAS assembler syntaxes, outputs binary, 
ELF32, ELF64, COFF, Win32, and Win64 object formats, and generates source 
debugging information in STABS, DWARF 2, and CodeView 8 formats.
#-------------------------------
%package vsyasm
Summary:      The Yasm Modular Assembler for Microsoft Visual Studio
Group:        Development/Tools
%description vsyasm
The Yasm Modular Assembler for Microsoft Visual Studio
#-------------------------------
%package ytasm
Summary:      ytasm - TASM Frontend For The Yasm Modular Assembler
Group:        Development/Tools
%description ytasm
The Yasm Modular Assembler is a portable, retargetable assembler written
under the new (2 or 3 clause) BSD license. ytasm is the TASM-compatible
frontend.
#-------------------------------
%package devel
Summary:      headers for the C compiler
Group:        Development/Libraries
%description devel
These headers are needed to compile C code.

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

GCC_VER_STR=`%{target_}gcc -dumpversion`
OPT47=`case $GCC_VER_STR in 4.[789].*) echo "-fno-asynchronous-unwind-tables" ;; esac`
LDFLAGS=" "

%if %{_arch} == "i386"
case $GCC_VER_STR in
  4.9.*) OPTFLAGS="-O2 -march=i586" ;;
  *)     OPTFLAGS="-O2 -march=i486" ;;
esac
OPTFLAGS="$OPTFLAGS -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer $OPT47"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-O2 $OPT47"
LDFLAGS=`case $GCC_VER_STR in 4.[56789].*) echo -static-libgcc ;; esac`
%endif
%if %{_arch} == "arm"
OPTFLAGS="-O2 -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access $OPT47"
%endif

OPTFLAGS="$OPTFLAGS -ffunction-sections -fdata-sections" 

CFLAGS="$OPTFLAGS -D_GNU_SOURCE -std=gnu99"
CXXFLAGS="$OPTFLAGS"
LDFLAGS="$LDFLAGS -Wl,--gc-sections"

%configure \
	--build=%{_build} \
%if %{_CROSS}
	--host=%{target} \
%endif
	--disable-nls \
	--disable-rpath \
	&>FConfigure_log.txt

make &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt

cp -a AUTHORS BSD.txt $RPM_BUILD_ROOT%{docdir}/
ln -s /usr/share/doc/gpl-2.0.txt $RPM_BUILD_ROOT%{docdir}/GNU_GPL-2.0
ln -s /usr/share/doc/lgpl-2.0.txt $RPM_BUILD_ROOT%{docdir}/GNU_LGPL-2.0


%if %{_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=0
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
%endif #_CROSS

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} -r %{DestDir} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 
DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-vsyasm-$SE $DD/%{name}-vsyasm-$DE
  mv %{name}-ytasm-$SE $DD/%{name}-ytasm-$DE
  mv %{name}-devel-$SE $DD/%{name}-devel-$DE
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
  TMP_TO=$DD/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r usr $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
popd
%endif  #BUILD_TAR

# ------------------- Files ------------------------------------------
%files
%{_bindir}/yasm
%{_mandir}/man1
%{docdir}

%files vsyasm
%{_bindir}/vsyasm

%files ytasm
%{_bindir}/ytasm

%files devel
%{_includedir}
%{_libdir}
%{_mandir}/man7
